==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "As suas definições foram atualizadas.",
"Activity" => "Atividade",
"A file or folder has been <strong>shared</strong>" => "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Foi <strong>criado</strong> um novo ficheiro ou pasta  numa pasta partilhada",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Foi <strong>alterado</strong> um ficheiro ou pasta numa pasta partilhada",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Foi <strong>apagado</strong> um ficheiro ou pasta numa pasta partilhada",
"You created %1\$s" => "Criou %1\$s",
"%2\$s created %1\$s" => "%2\$s criado %1\$s",
"You changed %1\$s" => "Alterado %1\$s",
"%2\$s changed %1\$s" => "%2\$s alterado %1\$s",
"You deleted %1\$s" => "Apagou %1\$s",
"%2\$s deleted %1\$s" => "%2\$s apagou %1\$s",
"You shared %1\$s with %2\$s" => "Partilhou %1\$s com %2\$s",
"You shared %1\$s with group %2\$s" => "Partilhou %1\$s com o grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s partilhou %1\$s consigo",
"You shared %1\$s via link" => "Você partilhou %1\$s através de um link",
"Activity notification" => "Notificação da Atividade",
"All Activities" => "Todas as Atividades",
"Activities by you" => "As sua atividades",
"Activities by others" => "Atividades de outros",
"Shares" => "Partilhas",
"Files" => "Ficheiros",
"%s and %s" => "%s e %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">%n mais</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n mais</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e %n mais","%s e %n mais"),
"Hello %s," => "Olá %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "A receção deste email deve-se à realização das seguintes ações, na última hora, por %s",
"You are receiving this email because in the last day the following things happened at %s" => "A receção deste email deve-se à realização das seguintes ações, no último dia, por %s",
"You are receiving this email because in the last week the following things happened at %s" => "A receção deste email deve-se à realização das seguintes ações, na última semana, por %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Irá ver aqui uma lista de eventos, quando começar a utilizar a sua %s",
"No more events to load" => "Sem mais eventos para carrregar",
"Enable RSS feed" => "Ativar receção de conteúdo por RSS",
"Notifications" => "Notificações",
"Mail" => "Correio",
"Stream" => "Fluxo",
"You need to set up your email address before you can receive notification emails." => "Precisa de configurar o seu endereço de e-mail antes de poder receber  a notificação por e-email.",
"Send emails:" => "Enviar emails:",
"Hourly" => "Hora a hora",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Activity feed" => "Atividade",
"Personal activity feed for %s" => "Últimas ações de %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "As suas definições foram atualizadas.",
"Activity" => "Atividade",
"A file or folder has been <strong>shared</strong>" => "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
"A new file or folder has been <strong>created</strong>" => "Foi <strong>criado</strong> um novo ficheiro ou pasta",
"A file or folder has been <strong>changed</strong>" => "Foi <strong>alterado</strong> um ficheiro ou pasta",
"A file or folder has been <strong>deleted</strong>" => "Foi <strong>apagado</strong> um ficheiro ou pasta",
"You created %1\$s" => "Criou %1\$s",
"%2\$s created %1\$s" => "%2\$s criado %1\$s",
"You changed %1\$s" => "Alterado %1\$s",
"%2\$s changed %1\$s" => "%2\$s alterado %1\$s",
"You deleted %1\$s" => "Apagou %1\$s",
"%2\$s deleted %1\$s" => "%2\$s apagou %1\$s",
"You shared %1\$s with %2\$s" => "Partilhou %1\$s com %2\$s",
"You shared %1\$s with group %2\$s" => "Partilhou %1\$s com o grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s partilhou %1\$s consigo",
"You shared %1\$s via link" => "Você partilhou %1\$s através de um link",
"Activity notification" => "Notificação da Atividade",
"All Activities" => "Todas as Atividades",
"Activities by you" => "As sua atividades",
"Activities by others" => "Atividades de outros",
"Shares" => "Partilhas",
"Files" => "Ficheiros",
"%s and %s" => "%s e %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">%n mais</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n mais</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e %n mais","%s e %n mais"),
"Hello %s," => "Olá %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "A receção deste email deve-se à realização das seguintes ações, na última hora, por %s",
"You are receiving this email because in the last day the following things happened at %s" => "A receção deste email deve-se à realização das seguintes ações, no último dia, por %s",
"You are receiving this email because in the last week the following things happened at %s" => "A receção deste email deve-se à realização das seguintes ações, na última semana, por %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Irá ver aqui uma lista de eventos, quando começar a utilizar a sua %s",
"No more events to load" => "Sem mais eventos para carrregar",
"Enable RSS feed" => "Ativar receção de conteúdo por RSS",
"Notifications" => "Notificações",
"Mail" => "Correio",
"Stream" => "Fluxo",
"Notify about my own actions" => "Notificar sobre as minhas próprias ações",
"You need to set up your email address before you can receive notification emails." => "Precisa de configurar o seu endereço de e-mail antes de poder receber  a notificação por e-email.",
"Send emails:" => "Enviar emails:",
"Hourly" => "Hora a hora",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Activity feed" => "Atividade",
"Personal activity feed for %s" => "Últimas ações de %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
